# Contributing

## Filing Issues

Whether you find a bug, typo or an API call that could be clarified, please [file an issue](https://github.com/realm/realm-dart/issues) on our GitHub repository.

When filing an issue, please provide as much of the following information as possible in order to help others fix it:

1. **Goals**
2. **Expected results**
3. **Actual results**
4. **Steps to reproduce**
5. **Code sample that highlights the issue** (full Flutter or Dart project that we can run ourselves are ideal)
6. **Version of Realm, Flutter and Dart**
7. **Version of desktop OS - Mac, Windows or Linux**
8. **Version of target mobile OS**

If you'd like to send us sensitive sample code to help troubleshoot your issue, you can email <help@realm.io> directly.

## Contributing Enhancements

We love contributions to Realm! If you'd like to contribute code, documentation, or any other improvements, please [file a Pull Request](https://github.com/realm/realm-dart/pulls) on our GitHub repository. Make sure to accept our [CLA](#CLA).

### CLA

Realm welcomes all contributions! The only requirement we have is that, like many other projects, we need to have a [Contributor License Agreement](https://en.wikipedia.org/wiki/Contributor_License_Agreement) (CLA) in place before we can accept any external code. Our own CLA is a modified version of the Apache Software Foundation’s CLA.

[Please submit your CLA electronically using our Google form](https://docs.google.com/forms/d/1ga5zIS9qnwwFPmbq-orSPsiBIXQjltKg7ytHd2NmDYo/viewform) so we can accept your submissions. The GitHub username you file there will need to match that of your Pull Requests. If you have any questions or cannot file the CLA electronically, you can email <help@realm.io>.

## Building from source

* Clone the repo
    ```shell
    git clone https://github.com/realm/realm-dart
    cd realm-dart
    git submodule update --init --recursive
    ```
* Activate [melos](https://melos.invertase.dev)
    ```shell
    dart pub global activate melos
    ```
    Make sure that `~/.pub-cache/bin/` is added to your `PATH`. Otherwise you need to prefix the following `melos` commands with `dart pub global run`.
    
* Setup project    
    ```shell
    melos bootstrap
    melos run setup
    ```

* Build artifacts
    ```shell
    melos run build
    ```

* Test
    ```shell
    melos run test
    ```

There are many more melos scripts to run, see [melos.yaml](melos.yaml) for details.
